@@ -17,6 +17,8 @@
 """rss2email-specific errors
 """
 
+import sys as _sys
+
 from . import LOG as _LOG
 from . import __version__, __url__, __email__
 
@@ -79,9 +81,8 @@ class SMTPAuthenticationError (SMTPConnectionError):
         message = (
             'could not authenticate with mail server {} as user {}'.format(
                 server, username))
-        super(SMTPConnectionError, self).__init__(
+        super(SMTPAuthenticationError, self).__init__(
             server=server, message=message)
-        self.server = server
         self.username = username
 
 
@@ -131,10 +132,10 @@ class InvalidFeedName (InvalidFeedConfig):
 
 
 class ProcessingError (FeedError):
-    def __init__(self, parsed, feed, **kwargs):
+    def __init__(self, parsed, feed, message=None, **kwargs):
         if message is None:
             message = 'error processing feed {}'.format(feed)
-        super(FeedError, self).__init__(feed=feed, message=message)
+        super(ProcessingError, self).__init__(feed=feed, message=message)
         self.parsed = parsed
 
     def log(self):
@@ -153,17 +154,17 @@ class ProcessingError (FeedError):
                     self.parsed.get('bozo_exception', "can't process"),
                     self.feed.url))
             _LOG.warning(_pprint.pformat(self.parsed))
-            _LOG.warning('rss2email', __version__)
-            _LOG.warning('feedparser', _feedparser.__version__)
-            _LOG.warning('html2text', _html2text.__version__)
-            _LOG.warning('Python', _sys.version)
+            _LOG.warning('rss2email {}'.format(__version__))
+            _LOG.warning('feedparser {}'.format(_feedparser.__version__))
+            _LOG.warning('html2text {}'.format(_html2text.__version__))
+            _LOG.warning('Python {}'.format(_sys.version))
             _LOG.warning('=== END HERE ===')
 
 
-class HTTPError (ProcessingError):
+class HTTPError (FeedError):
     def __init__(self, status, feed, **kwargs):
         message = 'HTTP status {} fetching feed {}'.format(status, feed)
-        super(FeedError, self).__init__(feed=feed, message=message)
+        super(HTTPError, self).__init__(feed=feed, message=message)
         self.status = status
 
 
@@ -220,4 +221,4 @@ class FeedIndexError (FeedsError, IndexError):
 class OPMLReadError (RSS2EmailError):
     def __init__(self, **kwargs):
         message = 'error reading OPML'
-        super(RSS2EmailError, self).__init__(message=message, **kwargs)
+        super(OPMLReadError, self).__init__(message=message, **kwargs)
